#!/bin/sh
# $Id: install.sh,v 1.1.1.1 2000/06/01 05:47:37 leonard Exp $
# David Leonard <david.leonard@csee.uq.edu.au>, 2000. Public domain.
#
# This small script modifies /etc/services and /etc/inetd.conf
# as per the uqwarnd(8) manual page. It only ever needs to be
# run once, as root, to install uqwarnd into inetd.

UQWARND=/usr/libexec/uqwarnd

if test '!' -x $UQWARND; then
	echo "$UQWARND: daemon not found or not executable" >&2
	exit 1
fi

#------------------------------------------------------------
# Modify /etc/services

if grep '^uqwarn' /etc/services >/dev/null; then
	: already there
else
	echo "Installing uqwarn entry into /etc/services..."
	echo "uqwarn 701/tcp" >> /etc/services || exit 1
fi

#------------------------------------------------------------
# Modify /etc/inetd.conf

if grep '^uqwarn' /etc/inetd.conf >/dev/null; then
	: already there
else
	echo "Installing uqwarn entry into /etc/inetd.conf..."
	echo "uqwarn	stream	tcp	nowait	nobody	$UQWARND	uqwarnd" >> /etc/inetd.conf || exit 1
	if test -f /var/run/inetd.pid; then
		echo "Restarting inetd..."
		kill -HUP `cat /var/run/inetd.pid`
	else
		echo "Note: inetd must be sent a SIGHUP for this change"
		echo "      to take effect."
	fi
fi

#------------------------------------------------------------
# Look at /etc/hosts.{allow,deny}

if test -f /etc/hosts.allow -o -f /etc/hosts.deny; then
	echo "Note: you may need to edit /etc/hosts.allow or /etc/hosts.deny"
	echo "      to permit connections to service 'uqwarnd'"
fi

echo "Installation complete."

