/*	$Id: uqwarnd.c,v 1.1.1.1 2000/06/01 05:47:37 leonard Exp $	*/
/* David Leonard <david.leonard@csee.uq.edu.au>, 2000. Public domain. */

/*
 * uqwarn - simplified.
 *
 * This program simply reads a message sent to the socket on stdin and 
 * syslogs it. ie this is basically logger(1) with tcpwrappers built in.
 */

#include <stdio.h>
#include <unistd.h>
#include <string.h>
#include <tcpd.h>
#include <syslog.h>
#include <err.h>

/* Severities levels for libwrap. */ 
int deny_severity = LOG_INFO;
int allow_severity = 0;

/* Convert a syslog facility/priority level into an integer. */
int
parse_level(name, table)
	const char *name;
	CODE * table;
{
	CODE * c;

	for (c = table; c->c_name; c++)
		if (strcmp(c->c_name, optarg) == 0)
			return c->c_val;
	return -1;
}

int
main(argc, argv)
	int argc;
	char **argv;
{
	int facility = LOG_DAEMON;
	int priority = LOG_WARNING;
	int error = 0;
	int ch;
	struct request_info ri;
	char message[8192];
	ssize_t len;

	/* Process options. */
	while ((ch = getopt(argc, argv, "p:f:")) != -1) {
		switch(ch) {
		case 'p':	
			priority = parse_level(optarg, prioritynames);
			if (priority < 0)
				errx(1, "unknown priority %s", optarg);
			break;

		case 'f':	
			facility = parse_level(optarg, facilitynames);
			if (priority < 0)
				errx(1, "unknown facility %s", optarg);
			break;

		default:
			error = 1;
			break;
		}
	}

	/* Handle any invocation problems. */
	if (error || argv[optind] != NULL) {
		fprintf(stderr, "usage: %s [-f facility] [-p priority]\n",
		    argv[0]);
		exit(1);
	}

	/* Find out who is sending us the message */
	request_init(&ri, RQ_DAEMON, "uqwarnd", RQ_FILE, STDIN_FILENO, 0);
	fromhost(&ri);
	if (hosts_access(&ri) == 0)
		exit(0);

	openlog("uqwarnd", LOG_CONS, facility);

	/* Read the uqwarn message. */
	while ((len = read(STDIN_FILENO, message, sizeof message)) > 0)
		syslog(priority, "%s: %.*s", eval_client(&ri), len, message);

	if (len < 0)
		err(1, "read");

	exit(0);
}
